pyLBM.storage.SOA
=================

.. currentmodule:: pyLBM.storage

.. autoclass:: SOA

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         SOA.reshape
         SOA.set_conserved_moments
         SOA.update



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         SOA.nspace
         SOA.nv
         SOA.shape
         SOA.size

